import React, { useState, useEffect } from "react";
import { Form, Input, Table, Image, Space, Button, Modal, message } from "antd";
import baseRequest from "../../utils/baseRequest";
import VideoPlayer from '../../components/VideoPlayer';
export default function DeletedPostReview() {
  //表头
  const columns = [
    {
      title: "动态信息",
      dataIndex: "info",
      key: "info",
      render: (data) => (
        <div>
          <p>
            动态id：<span className="text-red-400">{data.id}</span>
          </p>
          <p>
            点赞：<span className="text-red-400">{data.like}</span>
          </p>
          <p>
            创建时间：<span className="text-red-400">{data.ct}</span>
          </p>
        </div>
      ),
    },
    {
      title: "动态文案",
      dataIndex: "content",
      key: "content",
    },
    {
      title: "媒体",
      dataIndex: "media",
      key: "media",
      render: (data) => (
        <div>
          {data?.images?.map((item, index) => (
            <Image
              key={index}
              src={item.urls[0]}
              width={150}
              style={{ marginBottom: 10 }}
            />
          ))}
          {data?.videos?.map((item, index) => (
            <VideoPlayer key={index} url={item.urls[0]}/>
          ))}
        </div>
      ),
    },
    {
      title: "操作",
      dataIndex: "opeartion",
      key: "opeartion",
      render: (_, record) => (
        <div>
          <Space>
            <Space.Compact direction="vertical">
              <Button type="primary" onClick={() => onClickRecovery(record)}>
                恢复
              </Button>
            </Space.Compact>
          </Space>
        </div>
      ),
    },
  ];

  //点击恢复按钮
  const onClickRecovery = async (record) => {
    try {
      const base = baseRequest();
      const response = await fetch("/op/moment/update", {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          id: record.info.id,
          del_flag: 0,
          ...base,
        }),
      });
      const temData = await response.json();
      console.log(temData);
      if (temData.ret === -1) {
        alert(temData.msg);
        return;
      }
      setShowData(showData.filter((item) => item.info.id !== record.info.id));
    } catch (error) {
      console.error(error);
    }
  };

  //展示的数据
  const [showData, setShowData] = useState([]);

  //获取数据
  const getData = async () => {
    try {
      const base = baseRequest();
      const response = await fetch("/op/moment/list_deleted", {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          ct_upper_bound: Math.floor(new Date().getTime() / 1000),
          offset: 0,
          limit: 2000,
          ...base,
        }),
      });
      const temData = await response.json();
      if (temData.ret === -1) {
        alert(temData.msg);
        return;
      }
      //匹配表格格式
      const structedData = temData.data.list.map((item, index) => {
        return {
          key: index,
          info: {
            id: item.id,
            like: item.thumbs_up_num,
            ct: new Date(item.ct * 1000).toLocaleString(),
          },
          content: item.text,
          media: item.media_component,
        };
      });
      setShowData(structedData);
    } catch (error) {
      console.error(error);
    }
  };
  useEffect(() => {
    getData();
  }, []);

  return (
    <div className="w-full h-full">
      <Table
        columns={columns}
        dataSource={showData}
        pagination={{ pageSize: 20 }}
      />
    </div>
  );
}
